Package: injurytools
Title: A Toolkit for Sports Injury and Illness Data Analysis
Version: 2.0.1
Authors@R: c(
    person("Lore", "Zumeta Olaskoaga", , "lorezumeta@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-6141-1469")),
    person("Dae-Jin", "Lee", , "daelee@faculty.ie.edu", role = "ctb",
           comment = c(ORCID = "0000-0002-8995-8535"))
  )
Description: Sports Injury Data analysis aims to identify and describe the
    magnitude of the injury problem, and to gain more insights (e.g.
    determine potential risk factors) by statistical modelling approaches.
    The 'injurytools' package provides standardized routines and utilities
    that simplify such analyses. It offers functions for data preparation,
    informative visualizations and descriptive and model-based analyses.
License: MIT + file LICENSE
URL: https://github.com/lzumeta/injurytools,
        https://lzumeta.github.io/injurytools/
BugReports: https://github.com/lzumeta/injurytools/issues
Depends: R (>= 4.1.0)
Imports: checkmate, dplyr, forcats, ggplot2, lubridate, metR, purrr,
        rlang, scales, stats, stringr, tibble, tidyr, tidyselect, withr
Suggests: coxme, grid, gridExtra, kableExtra, knitr, lme4, MASS, pscl,
        RColorBrewer, rmarkdown, spelling, survival, survminer,
        testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-26 11:05:31 UTC; 72546574C
Author: Lore Zumeta Olaskoaga [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6141-1469>),
  Dae-Jin Lee [ctb] (ORCID: <https://orcid.org/0000-0002-8995-8535>)
Maintainer: Lore Zumeta Olaskoaga <lorezumeta@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-26 11:40:09 UTC
Built: R 4.6.0; ; 2026-04-29 20:10:08 UTC; unix
